/* vim: set noet ts=4 sw=4:
 *
 * Copyright (c) 2002-2009 Martin A. Godisch <martin@godisch.de>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "config.h"
#include "constants.h"

#include <assert.h>
#include <libintl.h>
#include <ncursesw/panel.h>
#include <stdlib.h>
#include <string.h>

#include "addscr.h"
#include "charset.h"
#include "data.h"
#include "latrine.h"
#include "mainscr.h"
#include "options.h"
#include "popup.h"
#include "readline.h"

#define _(string) gettext(string)
#define WINDOW_HEIGHT 12
#define WINDOW_WIDTH (80 - 2 * BORDER_WIDTH)

static PANEL  *pan = NULL;
static WINDOW *win = NULL;
static int label_len;

static int
callback(wint_t r, wint_t c, const void *udata)
{
	if ((r == OK && c == KEY_TAB) || (r == KEY_CODE_YES && c == KEY_BTAB))
		return c;
	else {
		fprintf(LOG, "r = %d = %04o, c = %d = %04o\n", r, r, c, c);
		return 0;
	}
}

static int
read_input(const int input_len, wchar_t *input[2], const int len[2])
{
	int i;

	readline(win, 5 + 1 * 2, label_len + 5, input_len, 1, direction / 2, input[1], 0, NULL, NULL);
	for (i = 0;;) {
		switch (readline(win, 5 + i * 2, label_len + 5, input_len, i, i == 0 ? direction % 2 : direction / 2,
			input[i], len[i], callback, NULL)) {
		case KEY_ESC:
			return 0;
		case KEY_RETURN:
			if (*input[0] != 0 && *input[1] != 0)
				return 1;
			i = *input[0] == 0 ? 0 : 1;
			break;
		case KEY_TAB:
		case KEY_BTAB:
			i++;
			i %= 2;
		}
	}
	return 0; // not reached
}

int
add_word(void)
{
	wchar_t *wp[2];
	wchar_t word[2][BUFSIZE];
	const int lp[2] = { BUFSIZE, BUFSIZE };
	const struct known *ck;
	struct known known;
	int c = 0;
	const char *s;

	pan = new_panel(win = newwin(WINDOW_HEIGHT, WINDOW_WIDTH, (sy - WINDOW_HEIGHT) / 2, (sx - WINDOW_WIDTH) / 2));
	wbkgdset(win, COLOR_PAIR(COLOR_BACK));
	wclear(win);
	if ((label_len = mbslen(language[0]) > mbslen(language[1]) ? mbslen(language[0]) : mbslen(language[1])) > MAX_LANG)
		label_len = MAX_LANG;
	mvwaddstr(win, 5, 2, language[0]); waddch(win, ':');
	mvwaddstr(win, 7, 2, language[1]); waddch(win, ':');
	wbkgdset(win, COLOR_PAIR(COLOR_LINE));
	wmove(win, 1, 0); wclrtoeol(win);
	mvwaddstr(win, 1, (60 - mbslen(s = /* TRANSLATORS: a window headline */ _("Add Translation"))) / 2, s);
	wmove(win, 10, 0); wclrtoeol(win);
	wattron (win, A_BOLD); waddstr(win, "  TAB ");
	wattroff(win, A_BOLD); waddstr(win, /* TRANSLATORS: button label for switching input lines */ _("Switch"));
	wattron (win, A_BOLD); waddstr(win, "  ENTER ");
	wattroff(win, A_BOLD); waddstr(win, /* TRANSLATORS: button label */ _("Add"));
	wattron (win, A_BOLD); waddstr(win, "  ESC ");
	wattroff(win, A_BOLD); waddstr(win, /* TRANSLATORS: button label */ _("Cancel"));
	wbkgdset(win, COLOR_PAIR(COLOR_BACK));
	box(win, 0, 0);
	update_panels();

	wp[0] = word[0]; *wp[0] = 0;
	wp[1] = word[1]; *wp[1] = 0;
	while (read_input(WINDOW_WIDTH - 7 - label_len, wp, lp)) {
		s2word(&known.word[0], wp[0]);
		s2word(&known.word[1], wp[1]);
		ck = &known;
		if ((c = add_translation(&known)) == 0) {
			wfree(&known.word[0]);
			wfree(&known.word[1]);
			break;
		}
		wfree(&known.word[0]);
		wfree(&known.word[1]);
		switch (c) {
			case -2:
				popup(_("Error"), _("Translation already exists in database."));
				break;
			default:
				popup(_("Error"), _("Inserting translation failed: %s"), dict_errmsg);
		}
	}
	hide_panel(pan);
	doupdate();
	return c;
}
