#!/bin/sh -e
#
# Copyright (c) 2002-2009 Martin A. Godisch <martin@godisch.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

export LC_ALL=C

test -e latrine.c
umask 022
date -R > released
cp -a /usr/share/automake-1.10/install-sh .
aclocal -I /usr/share/autoconf-archive -I m4
autoheader -Wall
autoconf -Wall
./configure
make mo distclean

DIR="`pwd | sed 's@/src$@@;s@.*/@@'`"
echo "$DIR" | grep -q -- - || exit 0

cd ../..
chmod -R go=u-w "$DIR"
version="`echo "$DIR" | sed 's@.*-@@'`"
tarname="latrine-${version}.tar.gz"
fakeroot tar cvzf $tarname --exclude .hg --exclude .hgignore --exclude debian "$DIR"
ln -sf $tarname latrine_$version.orig.tar.gz

if ! head -n 1 "$DIR/debian/changelog" | grep -q "^latrine (${version}-"
then
	echo "*** WARNING: version in debian/changelog out of date  ***"
fi
if ! grep -iq "AC_INIT.*[${version}]" "$DIR/src/configure.ac"
then
	echo "*** WARNING: version in configure.ac out of date  ***"
fi
if grep -iq "not yet released" "$DIR/CHANGES"
then
	echo "*** WARNING: release date in CHANGES file missing ***"
fi
if grep -iq "^${version}:" "$DIR/TODO"
then
	echo "*** WARNING: current version in TODO file present ***"
fi
for i in "$DIR"/src/po/*.po
do
	if grep -iq "fuzzy" $i
	then
		echo "*** WARNING: fuzzy strings in $i   ***"
	fi
done

echo -n "Sign $tarname? [y/N] "
read sign
if test "$sign" = y
then
	gpg -ab --default-key martin@godisch.de $tarname
else
	echo "No."
fi

cd $OLDPWD
exit 0
