/* vim: set noet ts=4 sw=4:
 *
 * Copyright (c) 2002-2009 Martin A. Godisch <martin@godisch.de>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "config.h"
#include "constants.h"

#include <libintl.h>
#include <ncursesw/panel.h>
#include <stdlib.h>
#include <string.h>

#include "data.h"
#include "delscr.h"
#include "charset.h"
#include "latrine.h"
#include "mainscr.h"
#include "memory.h"
#include "popup.h"
#include "readline.h"

#define _(string) gettext(string)
#define WINDOW_HEIGHT 12
#define WINDOW_WIDTH (80 - 2 * BORDER_WIDTH)

int
delete_word(const struct known *known)
{
	char *buffer;
	int n;
	int i;
	int nln;
	char **msg;
	int win_width = WINDOW_WIDTH;
	int win_height = 0;
	PANEL  *pan = NULL;
	WINDOW *win = NULL;
	const char *title;
	wint_t wch;

	MALLOC(buffer, (n = wcstombs(NULL, known->word[0].word, 0) + wcstombs(NULL, known->word[1].word, 0) +
			strlen(_("Do you really want to remove this translation?")) + 7));
	i = wcstombs(buffer, known->word[0].word, n);
	strcat(buffer, " -> ");
	wcstombs(buffer + i + 4, known->word[1].word, n);
	strcat(buffer, "\n\n");
	strcat(buffer, _("Do you really want to remove this translation?"));
	if ((nln = make_linebreaks(&msg, buffer, win_width - 4)) + 6 > sy - 4) {
		win_width = sx - 4;
		nln = make_linebreaks(&msg, buffer, win_width - 4);
	}
	if (nln > sy - 10)
		nln = sy - 10;
	win_height = nln + 6;
	if (win_height < 12)
		win_height = 12;
	free(buffer);

	pan = new_panel(win = newwin(win_height, win_width, (sy - win_height) / 2, (sx - win_width) / 2));
	wbkgdset(win, COLOR_PAIR(COLOR_BACK));
	wclear(win);
	wbkgdset(win, COLOR_PAIR(COLOR_LINE));
	wmove(win, 1, 0); wclrtoeol(win);
	mvwaddstr(win, 1, (60 - mbslen(title = /* TRANSLATORS: window headline */ _("Delete Translation"))) / 2, title);
	wmove(win, 10, 0); wclrtoeol(win);
	wattron (win, A_BOLD); waddstr(win, "  ENTER ");
	wattroff(win, A_BOLD); waddstr(win, /* TRANSLATORS: button label */ _("Delete"));
	wattron (win, A_BOLD); waddstr(win, "  ESC ");
	wattroff(win, A_BOLD); waddstr(win, _("Cancel"));
	wbkgdset(win, COLOR_PAIR(COLOR_BACK));
	box(win, 0, 0);
	for (i = 0; i < win_height - 6 && msg[i] != NULL; i++)
		mvwaddstr(win, i + (win_height - nln) / 2, 2, msg[i]);
	free_linebreaks(msg);
	wmove(win, win_height - 2, win_width - 2);
	update_panels();
	doupdate();

	nodelay(win, 0);
	for (;;) {
		wget_wch(win, &wch);
		switch (wch) {
			case KEY_RETURN:
				del_panel(pan);
				delwin(win);
				if (delete_translation(known->key) == 0)
					return 0;
				popup(_("Error"), _("Deleting translation failed: %s"), dict_errmsg);
				return -1;
			case KEY_ESC:
				del_panel(pan);
				delwin(win);
				return -1;
		}
	}
}
