/* vim: set noet ts=4 sw=4:
 *
 * Copyright (c) 2002-2009 Martin A. Godisch <martin@godisch.de>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef LATRINE_MEMORY_H
#define LATRINE_MEMORY_H

#define CALLOC(DST, NMEMB, SIZE) \
{ \
	if ((DST = calloc(NMEMB, SIZE)) == NULL) { \
		endwin(); \
		fprintf(LOG, "calloc: %m"); \
		exit(1); \
	} \
}

#define FREE(DST) \
{ \
	if (DST != NULL) { \
		free(DST); \
		DST = NULL; \
	} \
}

#define MALLOC(DST, SIZE) \
{ \
	if ((DST = malloc(SIZE)) == NULL) { \
		endwin(); \
		fprintf(LOG, "malloc: %m"); \
		exit(1); \
	} \
}

#define REALLOC(DST, SIZE) \
{ \
	if ((DST = realloc(DST, SIZE)) == NULL) { \
		endwin(); \
		fprintf(LOG, "realloc: %m"); \
		exit(1); \
	} \
}

#define STRDUP(DST, SRC) \
{ \
	if ((DST = strdup(SRC)) == NULL) { \
		endwin(); \
		fprintf(LOG, "strdup: %m"); \
		exit(1); \
	} \
}

#define STRNDUP(DST, SRC, SIZE) \
{ \
	if ((DST = strndup(SRC, SIZE)) == NULL) { \
		endwin(); \
		fprintf(LOG, "strndup: %m"); \
		exit(1); \
	} \
}

#define WMALLOC(DST, SIZE) \
{ \
	if ((DST = malloc((SIZE) * sizeof(wchar_t))) == NULL) { \
		endwin(); \
		fprintf(LOG, "malloc: %m"); \
		exit(1); \
	} \
}

#define WREALLOC(DST, SIZE) \
{ \
	if ((DST = realloc(DST, (SIZE) * sizeof(wchar_t))) == NULL) { \
		endwin(); \
		fprintf(LOG, "realloc: %m"); \
		exit(1); \
	} \
}

#define WCSDUP(DST, SRC) \
{ \
	if ((DST = wcsdup(SRC)) == NULL) { \
		endwin(); \
		fprintf(LOG, "wcsdup: %m"); \
		exit(1); \
	} \
}

#define WCSNDUP(DST, SRC, SIZE) \
{ \
	if ((DST = wcsndup(SRC, SIZE)) == NULL) { \
		endwin(); \
		fprintf(LOG, "wcsndup: %m"); \
		exit(1); \
	} \
}

#endif
