/* vim: set noet ts=4 sw=4:
 *
 * Copyright (c) 2002-2009 Martin A. Godisch <martin@godisch.de>.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "config.h"
#include "constants.h"

#include <libintl.h>
#include <ncursesw/panel.h>
#include <stdlib.h>
#include <string.h>

#include "popup.h"
#include "charset.h"
#include "latrine.h"
#include "memory.h"
#include "data.h"
#include "mainscr.h"
#include "readline.h"

#define _(string) gettext(string)

void
popup(const char *title, const char *text, ...)
{
	va_list ap;
	int n;
	char *buffer;
	int nln;
	char **msg;
	int win_width = 80 - 2 * BORDER_WIDTH;
	int win_height = 0;
	PANEL  *pan;
	WINDOW *win;
	int i;
	wint_t wch;

	va_start(ap, text);
	n = vsnprintf(NULL, 0, text, ap);
	va_end(ap);
	MALLOC(buffer, n + 1);
	va_start(ap, text);
	vsprintf(buffer, text, ap);
	va_end(ap);

	if ((nln = make_linebreaks(&msg, buffer, win_width - 4)) + 6 > sy - 4) {
		win_width = sx - 4;
		nln = make_linebreaks(&msg, buffer, win_width - 4);
	}
	if (nln > sy - BORDER_WIDTH)
		nln = sy - BORDER_WIDTH;
	win_height = nln + 6;
	if (win_height < 12)
		win_height = 12;
	free(buffer);

	pan = new_panel(win = newwin(win_height, win_width, (sy - win_height) / 2, (sx - win_width) / 2));
	wbkgdset(win, COLOR_PAIR(COLOR_BACK));
	wclear(win);
	wbkgdset(win, COLOR_PAIR(COLOR_LINE));
	wmove(win, 1, 0); wclrtoeol(win);
	mvwaddstr(win, 1, (win_width - mbslen(title)) / 2, title);
	wmove(win, win_height - 2, 0); wclrtoeol(win);
	wattron (win, A_BOLD); waddstr(win, "  ENTER ");
	wattroff(win, A_BOLD); waddstr(win, /* TRANSLATORS: button label */ _("OK"));
	wbkgdset(win, COLOR_PAIR(COLOR_BACK));
	box(win, 0, 0);
	for (i = 0; i < win_height - 6 && msg[i] != NULL; i++)
		mvwaddstr(win, i + (win_height - nln) / 2, 2, msg[i]);
	free_linebreaks(msg);
	wmove(win, win_height - 2, win_width - 2);
	update_panels();
	doupdate();

	keypad(win, TRUE);
	nodelay(win, 0);
	do wget_wch(win, &wch);
	while (wch != KEY_RETURN);
	del_panel(pan);
	delwin(win);
}
